==> torchtnt-nightly-2023.4.14.tar.gz: torchtnt-nightly-2023.4.14/README.md <==
TNT
==========

**TNT** is a library for PyTorch **t**rai**n**ing **t**ools and utilities.

<p align="center">
<a href="https://github.com/pytorch/tnt/actions?query=branch%3Amaster"><img src="https://img.shields.io/github/actions/workflow/status/pytorch/tnt/test.yml?branch=master" alt="build status"></a>
<a href="https://pypi.org/project/torchtnt"><img src="https://img.shields.io/pypi/v/torchtnt" alt="pypi version"></a>
<a href="https://pypi.org/project/torchtnt-nightly"><img src="https://img.shields.io/pypi/v/torchtnt-nightly?label=nightly" alt="pypi nightly version"></a>
<a href="https://codecov.io/gh/pytorch/tnt"><img src="https://codecov.io/gh/pytorch/tnt/branch/master/graph/badge.svg?token=DR67Q6T7YF" alt="codecov"></a>
<a href="https://github.com/pytorch/tnt/blob/master/LICENSE"><img src="https://img.shields.io/pypi/l/torchtnt" alt="bsd license"></a>
<a href="https://pytorch.org/tnt/"><img src="https://img.shields.io/badge/dynamic/json.svg?label=docs&url=https%3A%2F%2Fpypi.org%2Fpypi%2Ftorchtnt%2Fjson&query=%24.info.version&colorB=brightgreen&prefix=v" alt="documentation status"></a>
</div>


## Installation

TNT can be installed with pip. To do so, run:

```buildoutcfg
pip install torchtnt
```

If you run into issues, make sure that Pytorch is installed first.

You can also install the latest version from master. Just run:

```buildoutcfg
pip install git+https://github.com/pytorch/tnt.git@master
```

To update to the latest version from master:

```buildoutcfg
pip install --upgrade git+https://github.com/pytorch/tnt.git@master
```

==> torchtnt-nightly-2023.12.5.tar.gz: torchtnt-nightly-2023.12.5/README.md <==
TNT
==========

**TNT** is a library for PyTorch **t**rai**n**ing **t**ools and utilities.

<p align="center">
<a href="https://github.com/pytorch/tnt/actions?query=branch%3Amaster"><img src="https://img.shields.io/github/actions/workflow/status/pytorch/tnt/test.yml?branch=master" alt="build status"></a>
<a href="https://pypi.org/project/torchtnt"><img src="https://img.shields.io/pypi/v/torchtnt" alt="pypi version"></a>
<a href="https://anaconda.org/conda-forge/torchtnt"><img src="https://img.shields.io/conda/vn/conda-forge/torchtnt" alt="pypi version"></a>
<a href="https://pypi.org/project/torchtnt-nightly"><img src="https://img.shields.io/pypi/v/torchtnt-nightly?label=nightly" alt="pypi nightly version"></a>
<a href="https://codecov.io/gh/pytorch/tnt"><img src="https://codecov.io/gh/pytorch/tnt/branch/master/graph/badge.svg?token=DR67Q6T7YF" alt="codecov"></a>
<a href="https://github.com/pytorch/tnt/blob/master/LICENSE"><img src="https://img.shields.io/pypi/l/torchtnt" alt="bsd license"></a>
<a href="https://pytorch.org/tnt/"><img src="https://img.shields.io/badge/dynamic/json.svg?label=docs&url=https%3A%2F%2Fpypi.org%2Fpypi%2Ftorchtnt%2Fjson&query=%24.info.version&colorB=brightgreen&prefix=v" alt="documentation status"></a>
</div>


## Installation

TNT can be installed with pip:

```buildoutcfg
pip install torchtnt
```
Or, alternatively, via conda:

```buildoutcfg
conda install -c conda-forge torchtnt
```

If you run into issues, make sure that Pytorch is installed first.

You can also install the latest version from master. Just run:

```buildoutcfg
pip install git+https://github.com/pytorch/tnt.git@master
```

To update to the latest version from master:

```buildoutcfg
pip install --upgrade git+https://github.com/pytorch/tnt.git@master
```
